.. image:: https://travis-ci.org/asphalt-framework/asphalt-mongodb.svg?branch=master
  :target: https://travis-ci.org/asphalt-framework/asphalt-mongodb
  :alt: Build Status
.. image:: https://coveralls.io/repos/github/asphalt-framework/asphalt-mongodb/badge.svg?branch=master
  :target: https://coveralls.io/github/asphalt-framework/asphalt-mongodb?branch=master
  :alt: Code Coverage

This Asphalt framework component provides connectivity to MongoDB_ database servers.

It is a wrapper for the Motor_ library.

.. _MongoDB: https://www.mongodb.com/
.. _Motor: https://github.com/mongodb/motor

Project links
-------------

* `Documentation <http://asphalt-mongodb.readthedocs.org/en/latest/>`_
* `Help and support <https://github.com/asphalt-framework/asphalt/wiki/Help-and-support>`_
* `Source code <https://github.com/asphalt-framework/asphalt-mongodb>`_
* `Issue tracker <https://github.com/asphalt-framework/asphalt-mongodb/issues>`_
